@@ -1,6 +1,9 @@
 package Test::Mojo::Most;
 
-our $VERSION = '0.07';
+use strict;
+use warnings;
+
+our $VERSION = '0.08';
 
 1;
 
